@@ -2,6 +2,7 @@
 import json
 import os
 import requests
+import logging
 from base64 import b64encode
 from encode_utils.connection import Connection
 from requests.exceptions import HTTPError
@@ -43,6 +44,12 @@ class Accession(object):
         self.new_qcs = []
         self.raw_qcs = []
         self.current_user = self.get_current_user()
+        self.logger = logging.getLogger(__name__)
+        logging.basicConfig(
+            filename='accession.log',
+            format='%(asctime)s %(message)s',
+            level=logging.DEBUG
+        )
 
     def set_lab_award(self, lab, award):
         global COMMON_METADATA
@@ -104,25 +111,22 @@ class Accession(object):
     def accession_file(self, encode_file, gs_file):
         file_exists = self.file_at_portal(gs_file.filename)
         submitted_file_path = {'submitted_file_name': gs_file.filename}
-        if not file_exists:
-            local_file = self.backend.download(gs_file.filename)[0]
-            encode_file['submitted_file_name'] = local_file
-            encode_posted_file = self.conn.post(encode_file)
-            os.remove(local_file)
-            encode_posted_file = self.patch_file(encode_posted_file,
-                                                 submitted_file_path)
-            self.new_files.append(encode_posted_file)
-            return encode_posted_file
-        elif (file_exists
-              and file_exists.get('status')
-              in ['deleted', 'revoked']):
-            encode_file.update(submitted_file_path)
-            # Update the file to current user
-            # TODO: Reverse this when duplicate md5sums are enabled
-            encode_file.update({'submitted_by': self.current_user})
-            encode_patched_file = self.patch_file(file_exists, encode_file)
-            self.new_files.append(encode_patched_file)
-            return encode_patched_file
+        if file_exists:
+            self.logger.warning(
+                'Attempting to post duplicate file of %s with md5sum %s',
+                file_exists,
+                encode_file.get('md5sum')
+            )
+        local_file = self.backend.download(gs_file.filename)[0]
+        encode_file['submitted_file_name'] = local_file
+        encode_posted_file = self.conn.post(encode_file)
+        os.remove(local_file)
+        encode_posted_file = self.patch_file(
+            encode_posted_file,
+            submitted_file_path
+        )
+        self.new_files.append(encode_posted_file)
+        return encode_posted_file
         return file_exists
 
     def patch_file(self, encode_file, new_properties):
@@ -154,6 +158,15 @@ class Accession(object):
                             'genome', {}).get('ref_fa', '')]
             return assembly[0] if len(assembly) > 0 else ''
 
+    @property
+    def genome_annotation(self):
+        pipeline_name = self.analysis.metadata.get('workflowName')
+        if pipeline_name == 'mirna_seq_pipeline':
+            files = self.analysis.get_files(filekey='annotation')
+            if files:
+                annotation = self.file_at_portal(files[0].filename)
+            return annotation.get('genome_annotation', '')
+
     @property
     def lab_pi(self):
         return COMMON_METADATA['lab'].split('/labs/')[1].split('/')[0]
@@ -163,6 +176,10 @@ class Accession(object):
         return self.file_at_portal(
             self.analysis.raw_fastqs[0].filename).get('dataset')
 
+    @property
+    def assay_term_name(self):
+        return self.conn.get(self.dataset).get('assay_term_name')
+
     def file_from_template(self,
                            file,
                            file_format,
@@ -186,6 +203,8 @@ class Accession(object):
         }
         if file_format_type:
             obj['file_format_type'] = file_format_type
+        if self.genome_annotation:
+            obj['genome_annotation'] = self.genome_annotation
         obj[Connection.PROFILE_KEY] = 'file'
         obj.update(COMMON_METADATA)
         return obj
@@ -391,7 +410,10 @@ class Accession(object):
         step_run_id = self.get_step_run_id(encode_file)
         qc.update({
             'step_run':             step_run_id,
-            'status':               "released"})
+            'status':               "released",
+        })
+        if self.assay_term_name:
+            qc['assay_term_name'] = self.assay_term_name
         qc.update(COMMON_METADATA)
         qc[Connection.PROFILE_KEY] = profile
         # Shared QCs will have two or more file ids
